@@ -1,6 +1,8 @@
 import pyparsing as pp
 
-pp.ParserElement.setDefaultWhitespaceChars(' \t\r')
+from pydbml.parser.blueprints import ExpressionBlueprint
+
+pp.ParserElement.set_default_whitespace_chars(' \t\r')
 
 name = pp.Word(pp.alphanums + '_') | pp.QuotedString('"')
 
@@ -15,7 +17,7 @@ expression_literal = pp.Combine(
     pp.Suppress('`')
     + pp.CharsNotIn('`')[...]
     + pp.Suppress('`')
-).setParseAction(lambda s, l, t: f'({t[0]})')
+).set_parse_action(lambda s, lok, tok: ExpressionBlueprint(tok[0]))
 
 boolean_literal = (
     pp.CaselessLiteral('true')
